.. OpenSCM-Runner documentation master file, created by
   sphinx-quickstart on Thu Mar 19 12:35:34 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

OpenSCM-Runner
==============

.. include:: ../../README.rst
    :start-after: sec-begin-index
    :end-before: sec-end-index

.. include:: ../../README.rst
    :start-after: sec-begin-license
    :end-before: sec-end-license

.. toctree::
    :maxdepth: 2
    :caption: Documentation

    installation
    usage
    development

.. toctree::
    :maxdepth: 2
    :caption: API reference

    run
    settings
    utils

.. toctree::
    :maxdepth: 2
    :caption: Versions

    changelog

Index
-----

- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`
